getImagePath property
A function that retrieves the image path for a given state object.
Implementation
final String Function(T) getImagePath;
A function that retrieves the image path for a given state object.
final String Function(T) getImagePath;